<?php

/*
 * Copyright 2012-2014, Theia Post Slider, WeCodePixels, http://wecodepixels.com
 */

class TpsNavigationBar {
	// Get HTML for a navigation bar.
	public static function get_navigation_bar( $options ) {
		$defaults = array(
			'currentSlide' => null,
			'totalSlides'  => null,
			'prevPostId'   => null,
			'nextPostId'   => null,
			'prevPostUrl'  => null,
			'nextPostUrl'  => null,
			'id'           => null,
			'class'        => array(),
			'style'        => null,
			'title'        => null
		);
		$options  = array_merge( $defaults, $options );
		if ( ! is_array( $options['class'] ) ) {
			$options['class'] = array( $options['class'] );
		}

		// Get text
		if ( $options['totalSlides'] == 1 ) {
			$text = '';
		} else {
			$text = TpsOptions::get( 'navigation_text' );
			$text = str_replace( '%{currentSlide}', $options['currentSlide'], $text );
			$text = str_replace( '%{totalSlides}', $options['totalSlides'], $text );
		}

		// Get button URLs
		$prev = TpsNavigationBar::get_navigation_barButton( $options, false );
		$next = TpsNavigationBar::get_navigation_barButton( $options, true );

		// Title
		if ( ! $options['title'] ) {
			$options['title'] = '<span class="_helper">' . TpsOptions::get( 'helper_text' ) . '</span>';
		}

		// Final HTML
		$class   = array( 'theiaPostSlider_nav' );
		$class[] = '_' . TpsOptions::get( 'nav_horizontal_position' );
		if ( TpsOptions::get( 'theme_type' ) == 'font' ) {
			$class[] = 'fontTheme';
		}
		foreach ( $options['class'] as $c ) {
			$class[] = $c;
		}

		$html =
			'<div' . ( $options['id'] !== null ? ' id="' . $options['id'] . '"' : '' ) . ( $options['style'] !== null ? ' style="' . $options['style'] . '"' : '' ) . ' class="' . implode( $class, ' ' ) . '">' .
			'<div class="_buttons">' . $prev . '<span class="_text">' . $text . '</span>' . $next . '</div>' .
			'<div class="_title">' . $options['title'] . '</div>' .
			'</div>';

		return $html;
	}

	/*
	 * Get a button for a navigation bar.
	 * @param direction boolean False = prev; True = next;
	 */
	public static function get_navigation_barButton( $options, $direction ) {
		global $page, $pages;

		$directionName = $direction ? 'next' : 'prev';
		$url           = TpsMisc::get_post_page_url( $options['currentSlide'] + ( $direction ? 1 : - 1 ) );
		$leftText      = null;
		$rightText     = null;

		// Check if there isn't another page but there is another post.
		$urlIsAnotherPost = ! $url && $options[ $directionName . 'PostUrl' ];
		if ( $urlIsAnotherPost ) {
			$url = $options[ $directionName . 'PostUrl' ];
		}

		// Check what text we should display on the buttons.
		if ( TpsOptions::get( 'post_navigation' ) && ( ( $direction == false && $page == 1 ) || ( $direction == true && $page == count( $pages ) ) ) ) {
			$buttonText = TpsOptions::get( $directionName . '_text_post' );
		} else {
			$buttonText = TpsOptions::get( $directionName . '_text' );
		}

		switch ( TpsOptions::get( 'theme_type' ) ) {
			case 'font':
				$text  = $directionName == 'next' ? TpsOptions::get_font_icon( 'right' ) : TpsOptions::get_font_icon( 'left' );
				$width = 0;

				if ( $directionName == 'next' ) {
					$leftText = $buttonText;
				} else {
					$rightText = $buttonText;
				}
				break;

			case 'classic':
				$text      = $buttonText;
				$leftText  = '';
				$rightText = '';

				if ( $urlIsAnotherPost ) {
					$width = TpsOptions::get( 'button_width_post' );
				} else {
					$width = TpsOptions::get( 'button_width' );
				}
				break;

			default:
				return '';
		}

		$style = $width == 0 ? '' : 'style="width: ' . $width . 'px"';

		$htmlPart1 = '<span class="_1">' . $leftText . '</span><span class="_2" ' . $style . '>';
		$htmlPart2 = '</span><span class="_3">' . $rightText . '</span>';

		// HTML
		$html = $htmlPart1 . $text . $htmlPart2;
		if ( $url ) {
			$button = '<a href="' . $url . '" class="_button _' . $directionName . '">' . $html . '</a>';
		} else {
			$button = '<span class="_button _' . $directionName . ' _disabled">' . $html . '</span>';
		}

		return $button;
	}
}